@@ -680,12 +680,12 @@ class VacBot():
     def GetCleanLogs(self):
         self.exc_command('GetCleanLogs')
 
-    def CustomArea(self, map_position='', cleanings=1):
-        self.exc_command('clean', {'act': 'start', 'content': map_position, 'count': cleanings, 'type': 'customArea'})
+    def CustomArea(self, map_position, cleanings=1):
+        self.exc_command('clean', {'act': 'start', 'content': str(map_position), 'count': cleanings, 'type': 'customArea'})
         self.refresh_statuses()
 
-    def SpotArea(self, area='', cleanings=1):
-        self.exc_command('clean', {'act': 'start', 'content': area, 'count': cleanings, 'type': 'spotArea'})
+    def SpotArea(self, area, cleanings=1):
+        self.exc_command('clean', {'act': 'start', 'content': str(area), 'count': cleanings, 'type': 'spotArea'})
         self.refresh_statuses()
 
     def SetFanSpeed(self, speed=1):
