@@ -198,7 +198,7 @@ def run(actions, debug):
         for action in actions:
             click.echo("performing " + str(action.vac_command))
             #vacbot.SetFanSpeed('normal')
-            vacbot.GetCleanLogs()
+            vacbot.CustomArea('-1008,-2302,250,-3240',1)
             vacbot.refresh_statuses()
             #vacbot.request_all_statuses()
             #action.wait.wait(vacbot)
